@@ -15,8 +15,8 @@ import sys
 from datetime import datetime
 from typing import Any, Dict, Type
 
+from boto3.botocore_stubs import ClientError as BotocoreClientError
 from botocore.client import ClientMeta
-from botocore.exceptions import ClientError as Boto3ClientError
 
 from mypy_boto3_sagemaker_a2i_runtime.paginator import ListHumanLoopsPaginator
 from mypy_boto3_sagemaker_a2i_runtime.type_defs import (
@@ -37,18 +37,18 @@ __all__ = ("AugmentedAIRuntimeClient",)
 
 
 class Exceptions:
-    ClientError: Type[Boto3ClientError]
-    ConflictException: Type[Boto3ClientError]
-    InternalServerException: Type[Boto3ClientError]
-    ResourceNotFoundException: Type[Boto3ClientError]
-    ServiceQuotaExceededException: Type[Boto3ClientError]
-    ThrottlingException: Type[Boto3ClientError]
-    ValidationException: Type[Boto3ClientError]
+    ClientError: Type[BotocoreClientError]
+    ConflictException: Type[BotocoreClientError]
+    InternalServerException: Type[BotocoreClientError]
+    ResourceNotFoundException: Type[BotocoreClientError]
+    ServiceQuotaExceededException: Type[BotocoreClientError]
+    ThrottlingException: Type[BotocoreClientError]
+    ValidationException: Type[BotocoreClientError]
 
 
 class AugmentedAIRuntimeClient:
     """
-    [AugmentedAIRuntime.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/sagemaker-a2i-runtime.html#AugmentedAIRuntime.Client)
+    [AugmentedAIRuntime.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/sagemaker-a2i-runtime.html#AugmentedAIRuntime.Client)
     """
 
     meta: ClientMeta
@@ -56,17 +56,17 @@ class AugmentedAIRuntimeClient:
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/sagemaker-a2i-runtime.html#AugmentedAIRuntime.Client.can_paginate)
+        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/sagemaker-a2i-runtime.html#AugmentedAIRuntime.Client.can_paginate)
         """
 
     def delete_human_loop(self, HumanLoopName: str) -> Dict[str, Any]:
         """
-        [Client.delete_human_loop documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/sagemaker-a2i-runtime.html#AugmentedAIRuntime.Client.delete_human_loop)
+        [Client.delete_human_loop documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/sagemaker-a2i-runtime.html#AugmentedAIRuntime.Client.delete_human_loop)
         """
 
     def describe_human_loop(self, HumanLoopName: str) -> DescribeHumanLoopResponseTypeDef:
         """
-        [Client.describe_human_loop documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/sagemaker-a2i-runtime.html#AugmentedAIRuntime.Client.describe_human_loop)
+        [Client.describe_human_loop documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/sagemaker-a2i-runtime.html#AugmentedAIRuntime.Client.describe_human_loop)
         """
 
     def generate_presigned_url(
@@ -77,7 +77,7 @@ class AugmentedAIRuntimeClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/sagemaker-a2i-runtime.html#AugmentedAIRuntime.Client.generate_presigned_url)
+        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/sagemaker-a2i-runtime.html#AugmentedAIRuntime.Client.generate_presigned_url)
         """
 
     def list_human_loops(
@@ -90,7 +90,7 @@ class AugmentedAIRuntimeClient:
         MaxResults: int = None,
     ) -> ListHumanLoopsResponseTypeDef:
         """
-        [Client.list_human_loops documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/sagemaker-a2i-runtime.html#AugmentedAIRuntime.Client.list_human_loops)
+        [Client.list_human_loops documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/sagemaker-a2i-runtime.html#AugmentedAIRuntime.Client.list_human_loops)
         """
 
     def start_human_loop(
@@ -101,15 +101,15 @@ class AugmentedAIRuntimeClient:
         DataAttributes: HumanLoopDataAttributesTypeDef = None,
     ) -> StartHumanLoopResponseTypeDef:
         """
-        [Client.start_human_loop documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/sagemaker-a2i-runtime.html#AugmentedAIRuntime.Client.start_human_loop)
+        [Client.start_human_loop documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/sagemaker-a2i-runtime.html#AugmentedAIRuntime.Client.start_human_loop)
         """
 
     def stop_human_loop(self, HumanLoopName: str) -> Dict[str, Any]:
         """
-        [Client.stop_human_loop documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/sagemaker-a2i-runtime.html#AugmentedAIRuntime.Client.stop_human_loop)
+        [Client.stop_human_loop documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/sagemaker-a2i-runtime.html#AugmentedAIRuntime.Client.stop_human_loop)
         """
 
     def get_paginator(self, operation_name: Literal["list_human_loops"]) -> ListHumanLoopsPaginator:
         """
-        [Paginator.ListHumanLoops documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/sagemaker-a2i-runtime.html#AugmentedAIRuntime.Paginator.ListHumanLoops)
+        [Paginator.ListHumanLoops documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/sagemaker-a2i-runtime.html#AugmentedAIRuntime.Paginator.ListHumanLoops)
         """
